==> pyrogramv1-1.4.16-py3-none-any.whl: pyrogramv1/raw/base/document_attribute.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogramv1 import raw
from pyrogramv1.raw.core import TLObject

DocumentAttribute = Union[raw.types.DocumentAttributeAnimated, raw.types.DocumentAttributeAudio, raw.types.DocumentAttributeFilename, raw.types.DocumentAttributeHasStickers, raw.types.DocumentAttributeImageSize, raw.types.DocumentAttributeSticker, raw.types.DocumentAttributeVideo]


# noinspection PyRedeclaration
class DocumentAttribute:  # type: ignore
    """This base type has 7 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`DocumentAttributeAnimated <pyrogramv1.raw.types.DocumentAttributeAnimated>`
            - :obj:`DocumentAttributeAudio <pyrogramv1.raw.types.DocumentAttributeAudio>`
            - :obj:`DocumentAttributeFilename <pyrogramv1.raw.types.DocumentAttributeFilename>`
            - :obj:`DocumentAttributeHasStickers <pyrogramv1.raw.types.DocumentAttributeHasStickers>`
            - :obj:`DocumentAttributeImageSize <pyrogramv1.raw.types.DocumentAttributeImageSize>`
            - :obj:`DocumentAttributeSticker <pyrogramv1.raw.types.DocumentAttributeSticker>`
            - :obj:`DocumentAttributeVideo <pyrogramv1.raw.types.DocumentAttributeVideo>`
    """

    QUALNAME = "pyrogramv1.raw.base.DocumentAttribute"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/document-attribute")

==> pyrogramv1-1.4.17-py3-none-any.whl: pyrogramv1/raw/base/document_attribute.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogramv1 import raw
from pyrogramv1.raw.core import TLObject

DocumentAttribute = Union[raw.types.DocumentAttributeAnimated, raw.types.DocumentAttributeAudio, raw.types.DocumentAttributeCustomEmoji, raw.types.DocumentAttributeFilename, raw.types.DocumentAttributeHasStickers, raw.types.DocumentAttributeImageSize, raw.types.DocumentAttributeSticker, raw.types.DocumentAttributeVideo]


# noinspection PyRedeclaration
class DocumentAttribute:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`DocumentAttributeAnimated <pyrogramv1.raw.types.DocumentAttributeAnimated>`
            - :obj:`DocumentAttributeAudio <pyrogramv1.raw.types.DocumentAttributeAudio>`
            - :obj:`DocumentAttributeCustomEmoji <pyrogramv1.raw.types.DocumentAttributeCustomEmoji>`
            - :obj:`DocumentAttributeFilename <pyrogramv1.raw.types.DocumentAttributeFilename>`
            - :obj:`DocumentAttributeHasStickers <pyrogramv1.raw.types.DocumentAttributeHasStickers>`
            - :obj:`DocumentAttributeImageSize <pyrogramv1.raw.types.DocumentAttributeImageSize>`
            - :obj:`DocumentAttributeSticker <pyrogramv1.raw.types.DocumentAttributeSticker>`
            - :obj:`DocumentAttributeVideo <pyrogramv1.raw.types.DocumentAttributeVideo>`
    """

    QUALNAME = "pyrogramv1.raw.base.DocumentAttribute"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/document-attribute")
